

clear
cd C:\Users\Blackkuma\Desktop\code\stata //更换路径即可运行

log using "donation.smcl", replace  // 打开日志
*本代码使用stata15运行

//注意：由于do文件中有需要logout命令来输出结果，该命令会同时退出日志，因此需要在logout出现后使用log using "donation.smcl", append
use donation202408.dta 

******************************************************************
{ //写在前面：变量说明
//Treat: 两个维度的处理编码，共3*3=9种，对应正文其中信息维度以I0、I1、I2表示没有单价信息、提供单价信息以及提供单价信息并提供在线计算器，补贴维度以no、match和rebate表示没有补贴、配套补贴和返利补贴
//treatment: 信息维度的编码。I0表示没有单价信息，I1表示提供单价信息，I2表示提供单价信息并提供根据单价计算的捐赠单位数的"在线计算器"
//Subsidy：补贴维度的编码。no表示无补贴，match表示配套补贴，rebate表示返利补贴
//ID：全部被试统一编码
//sessioncode：实验场次的代码
//participantcode：被试的代码，可以发现一个编码重复了3次，方便后续按照长数据和短数据两张方式做分析
//Subject：按照每个treatment（I0, I1和I2）无重复进行的被试编码，实际上与participantcode等价，只是为了方便观察每个treatment的人数
//NetDona：净捐赠，结合后面的Match和Rebate的值可以判断是处于何种补贴制度下的净捐赠，每个被试的三行数据分别表示三种制度下的净捐赠
//Dona：名义捐赠，结合后面的Match和Rebate的值可以判断是处于何种补贴制度下的名义捐赠，每个被试的三行数据分别表示三种制度下的名义捐赠 
//Cha：加总捐赠，结合后面的Match和Rebate的值可以判断是处于何种补贴制度下的加总捐赠，每个被试的三行数据分别表示三种制度下的加总捐赠 
//Match: 如果是配套补贴则为1，否则为0
//Rebate: 如果是返利补贴为1，否则为0
//I1：是否是I1处理，1表示为I1，0表示其他
//I2：是否是I2处理，1表示为I2，0表示其他
//I1_Match: I1与Match的交互项
//I1_Rebate: I1与Rebate的交互项 
//I2_Match: I2与Match的交互项 
//I2_Rebate: I2与Rebate的交互项
//IsInformation： 单价信息披露强度变量IsInformation，其中I0、I1和I2分别对应IsInformation变量的0、1和2
//IsInformation_Match：IsInformation与Match的交互
//IsInformation_Rebate：IsInformation与Rebate的交互
//Donate：在无补贴下的名义捐赠，每个被试三行数据是一样的 
//DonateMatch：配套补贴下的名义捐赠，每个被试三行数据是一样的
//DonateRebate：返利补贴下的名义捐赠，每个被试三行数据是一样的
//NetDonate：在无补贴下的净捐赠，每个被试三行数据是一样的 
//NetDonateMatch：配套补贴下的净捐赠，每个被试三行数据是一样的 
//NetDonateRebate：在无补贴下的净捐赠，每个被试三行数据是一样的
//NetDonateM4: 4分类变量，对应单价6，分别是1：小于6；2：等于6；3大于6小于12；4： 12 
//NetDonateM8: 8分类变量，单价6，考虑有补贴的情况，实际单价为3，因此分为8类，分别是1：小于3；2：等于3；3：大于3小于6；4： 等于6；5：大于6小于9；6：等于9；7：大于9小于12；8：等于12
//male：性别，男为1，女为0
//age：年龄
//ganbu：是否为学生干部，是为1，否为0 
//communist：是否为党员，是为1，否为0
//consume：消费，1="1000元以下"; 2="1000到1499元人民币"; 3="1500到1999元人民币"; 4="2000到3000元人民币"; 5="3000到4000元人民币"; 6="4000到5000元人民币"; 7="5000元以上";
//citizen：被试是否来自城市，1表示来自城市，0表示来自农村
//yearsofcollege： 大学几年级，研究生1年级为5，以此类推
//IsEM：是否为经管类学生，1表示为经管类，0表示非经管类
//directway： 有没有给他人指过路，1表示有，0表示没有
//impurealtruism： 是否会为做了好事而感到高兴，1表示会，0表示不会
//freelunch： 是否知道免费午餐计划，1表示知道，0表示不知道
//feedback： 是否希望知道受捐者实际收益情况，1表示希望知道，0表示不希望知道
//dictatoroffer：初始账户为10元的独断者博弈中给对方的数量
}

******************************************************************
{ //模块1 正文表格
//正文 表1：各实验组净捐赠指标，对净捐赠的描述性统计，陈列各treatment下净捐赠的均值和方差。正文中为了美观重新整理了表格
tabstat  NetDona, by(Treat) s(mean sd N) long nototal f(%6.2f) 
logout, save("表1 描述性统计结果.docx") word replace: tabstat NetDona, by(Treat) statistics(mean sd N) long nototal format(%6.2f)

log using "donation.smcl", append
//正文 表2：净捐赠的tobit回归
//定义控制变量
global controls male age ganbu communist consume citizen yearsofcollege IsEM directway impurealtruism freelunch feedback dictatoroffer  

tobit NetDona I1 I2, vce(cluster ID)  ll(0) ul(12) 
est sto t1
tobit NetDona Match Rebate i.ID, vce(cluster ID)   ll(0) ul(12)  
est sto t2
tobit NetDona I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate, vce(cluster ID)   ll(0) ul(12)
est sto t3
tobit NetDona I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate $controls, vce(cluster ID)   ll(0) ul(12)
est sto t4
tobit NetDona IsInformation, vce(cluster ID)   ll(0) ul(12)
est sto t5
tobit NetDona IsInformation Match Rebate IsInformation_Match IsInformation_Rebate, vce(cluster ID)   ll(0) ul(12)
est sto t6
tobit NetDona IsInformation Match Rebate IsInformation_Match IsInformation_Rebate $controls, vce(cluster ID)   ll(0) ul(12)
est sto t7
esttab t* using tobit.rtf, nogap compress r2 scalar(N) star (* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f)  r2(%6.3f) /// 
 keep (I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate IsInformation IsInformation_Match IsInformation_Rebate $controls _cons) ///
 order (I1 I2 IsInformation Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate  IsInformation_Match IsInformation_Rebate) replace

//正文 表3：mlogit回归边际效应	
forval i=1/4{
mlogit NetDonateM4 I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate $controls, vce(cluster ID) base(2)
estpost margins, dydx(*) predict(pr outcome(`i'))
est sto ma`i'
}
esttab ma1 ma2 ma3 ma4 using mlogit_margins.rtf, star(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) pr2 scalar(N) nobaselevels noobs nonumbers nogap compress ///
mlabels("小于6" "等于6" "6到12" "等于12") replace

 
}

****************************************************************** 
{ //模块2 正文结果中没有在表格中提供的统计检验
//正文中的位置：表1下方文字表达中涉及到的统计检验
//信息对净捐赠的作用，信息维度是between subject 设计，所以用Two-sample Wilcoxon rank-sum (Mann–Whitney) test
//(1)无补贴条件下
ranksum NetDona if (treatment == "I0" | treatment == "I1") & Subsidy == 1, by(treatment) 
ranksum NetDona if (treatment == "I0" | treatment == "I2") & Subsidy == 1, by(treatment) 
ranksum NetDona if (treatment == "I1" | treatment == "I2") & Subsidy == 1, by(treatment) 
//(2)配套补贴条件下
ranksum NetDona if (treatment == "I0" | treatment == "I1") & Subsidy == 2, by(treatment) 
ranksum NetDona if (treatment == "I0" | treatment == "I2") & Subsidy == 2, by(treatment)
//(3)返利补贴条件下
ranksum NetDona if (treatment == "I0" | treatment == "I1") & Subsidy == 3, by(treatment) 
ranksum NetDona if (treatment == "I0" | treatment == "I2") & Subsidy == 3, by(treatment)
//补贴制度对净捐赠的作用，补贴制度维度采用within subject设计，故采用Wilcoxon signed-rank test
//（1）I0条件
signrank NetDonate = NetDonateMatch if treatment == "I0" & Subsidy == 1 //注意，NetDonate和NetDonateMatch每个人的数据有三条一样的，应该只取其中一行，因此限制Subsidy == 1，以下同理
signrank NetDonate = NetDonateRebate if treatment == "I0" & Subsidy == 1
signrank NetDonateMatch = NetDonateRebate if treatment == "I0" & Subsidy == 1
//（2）I1条件
signrank NetDonate = NetDonateMatch if treatment == "I1" & Subsidy == 1 
signrank NetDonate = NetDonateRebate if treatment == "I1" & Subsidy == 1
signrank NetDonateMatch = NetDonateRebate if treatment == "I1" & Subsidy == 1
//（2）I2条件
signrank NetDonate = NetDonateMatch if treatment == "I2" & Subsidy == 1 
signrank NetDonate = NetDonateRebate if treatment == "I2" & Subsidy == 1
signrank NetDonateMatch = NetDonateRebate if treatment == "I2" & Subsidy == 1
}

******************************************************************
{ //模块3 附录表格
//附录 表A1平衡性检验 
iebaltab $controls if Subsidy == 1, savex(ttest) replace grpvar(treatment) browse   //可点击 ttest.xlsx查看

//附录 表A2不同性别的净捐赠
use donation202408.dta, clear  //由于平衡性检验改变了数据，需重新调用数据
bys male: tabstat  NetDona, by(Treat) s(mean sd) long nototal f(%6.2f) 
logout, save("表A2 不同性别的净捐赠.docx") word replace: bys male: tabstat NetDona, by(Treat) statistics(mean sd) long nototal format(%6.2f)

log using "donation.smcl", append
//附录 表A3：净捐赠分性别的tobit回归
tobit NetDona I1 I2 if male==1, vce(cluster ID)  ll(0) ul(12) 
est sto g1
tobit NetDona Match Rebate i.ID if male==1, vce(cluster ID)   ll(0) ul(12)
est sto g2
tobit NetDona I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate if male==1, vce(cluster ID)   ll(0) ul(12)
est sto g3
tobit NetDona I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate $controls if male==1, vce(cluster ID)   ll(0) ul(12)
est sto g4
tobit NetDona I1 I2 if male==0, vce(cluster ID)  ll(0) ul(12) 
est sto g5
tobit NetDona Match Rebate i.ID if male==0, vce(cluster ID)   ll(0) ul(12)
est sto g6
tobit NetDona I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate if male==0, vce(cluster ID)   ll(0) ul(12)
est sto g7
tobit NetDona I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate $controls if male==0, vce(cluster ID)   ll(0) ul(12)
est sto g8

esttab g1 g2 g3 g4 g5 g6 g7 g8 using tobit_gender.rtf, nogap compress r2 scalar(N) star (* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f)  r2(%6.3f) /// 
 keep (I1 I2 Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate IsInformation IsInformation_Match IsInformation_Rebate $controls _cons) ///
 order (I1 I2 IsInformation Match Rebate I1_Match I1_Rebate I2_Match I2_Rebate  IsInformation_Match IsInformation_Rebate) replace

}


******************************************************************
{ //模块4 正文图 本文出图使用matlab，但数据来源stata

//正文 图3 a b 两张图，需要均值、95%置信区间（上界）以及变量两两之间的显著性
//第一步：得到均值数据和95%置信区间（上界）数据，可以用以下命令，并手动获取其中的均值与95%置信区间上界数据，拷贝至matlab图文件（Figure2a_BarNetdonate.m和Figure2b_BarNetdonate.m）
bys Treat: ttest NetDona = 0
//第二步：获取两两比较的p值，在matlab画图程序（Figure3a_BarNetdonate.m和Figure3b_BarNetdonate.m）中添加显著性标志*，其中*：10%，**：5%；***：1%)
//图3a：信息对净捐赠的作用，信息维度是between subject 设计，所以用Two-sample Wilcoxon rank-sum (Mann–Whitney) test
//(1)无补贴条件下
ranksum NetDona if (treatment == "I0" | treatment == "I1") & Subsidy == 1, by(treatment) 
ranksum NetDona if (treatment == "I0" | treatment == "I2") & Subsidy == 1, by(treatment) 
ranksum NetDona if (treatment == "I1" | treatment == "I2") & Subsidy == 1, by(treatment) 
//(2)配套补贴条件下
ranksum NetDona if (treatment == "I0" | treatment == "I1") & Subsidy == 2, by(treatment) 
ranksum NetDona if (treatment == "I0" | treatment == "I2") & Subsidy == 2, by(treatment)
//(3)返利补贴条件下
ranksum NetDona if (treatment == "I0" | treatment == "I1") & Subsidy == 3, by(treatment) 
ranksum NetDona if (treatment == "I0" | treatment == "I2") & Subsidy == 3, by(treatment)
//图3b：补贴制度对净捐赠的作用，补贴制度维度采用within subject设计，故采用Wilcoxon signed-rank test
//（1）I0条件
signrank NetDonate = NetDonateMatch if treatment == "I0" & Subsidy == 1 //注意，NetDonate和NetDonateMatch每个人的数据有三条一样的，应该只取其中一行，因此限制Subsidy == 1，以下同理
signrank NetDonate = NetDonateRebate if treatment == "I0" & Subsidy == 1
signrank NetDonateMatch = NetDonateRebate if treatment == "I0" & Subsidy == 1
//（2）I1条件
signrank NetDonate = NetDonateMatch if treatment == "I1" & Subsidy == 1 
signrank NetDonate = NetDonateRebate if treatment == "I1" & Subsidy == 1
signrank NetDonateMatch = NetDonateRebate if treatment == "I1" & Subsidy == 1
//（2）I2条件
signrank NetDonate = NetDonateMatch if treatment == "I2" & Subsidy == 1 
signrank NetDonate = NetDonateRebate if treatment == "I2" & Subsidy == 1
signrank NetDonateMatch = NetDonateRebate if treatment == "I2" & Subsidy == 1

//正文 图4 净捐赠4分类分布图（共6张子图），这里需要每一个类型的捐赠的占比数据
bys Treat: egen n_Subject = max(Subject)    //按每种处理分布计算总人次
bys Treat NetDonateM4: egen n_NetDonateM4 = count(NetDonateM4)  //进一步按照每个分类计算总人次
gen fraction4 = n_NetDonateM4/n_Subject    //计算百分比
bys Treat NetDonateM4: gen n = _n 
keep if n == 1  //去除重复值
keep Treat NetDonateM4 fraction4  //保留所需数据，并将此数据分别按照无补贴、配套和返利三种情况，将I0与I1、I0与I2对应拷贝到6个matlab出图程序中。对应的matlab文件名：Figure4a_BarNetdonate4_0_I1.m、Figure4b_BarNetdonate4_M_I1.m、Figure4c_BarNetdonate4_R_I1.m、Figure4d_BarNetdonate4_0_I2.m、Figure4e_BarNetdonate4_M_I2.m、Figure4f_BarNetdonate4_R_I2.m，注意，若某个分类不存在需在matlab中补充该分类，并填入0

//正文 图5 净捐赠8分类分布图（共6张子图）
use donation202408.dta, clear   //因为数据被改动过了，要重新读取
bys Treat: egen n_Subject = max(Subject)    //按每种处理分布计算总人次
bys Treat NetDonateM8: egen n_NetDonateM8 = count(NetDonateM8)  //进一步按照每个分类计算总人次
gen fraction8 = n_NetDonateM8/n_Subject    //计算百分比
bys Treat NetDonateM8: gen n = _n 
keep if n == 1  //去除重复值
keep Treat NetDonateM8 fraction8 
//保留所需数据，并将此数据分别按照无补贴、配套和返利三种情况，将I0与I1、I0与I2对应拷贝到6个matlab出图程序中。对应的matlab文件名：Figure5a_BarNetdonate8_0_I1.m、Figure5b_BarNetdonate8_M_I1.m、Figure5c_BarNetdonate8_R_I1.m、Figure5d_BarNetdonate8_0_I2.m、Figure5e_BarNetdonate8_M_I2.m、Figure5f_BarNetdonate8_R_I2.m，注意，若某个分类不存在需在matlab中补充该分类，并填入0)
}


log close // 关闭日志
